@@ -85,14 +85,16 @@ class Activity(models.Model):
         return output
 
     @cached_property
-    def get_image(self):
+    def image(self):
         """
-        Attempts to get a representative image from a content_object.get_image method. 
-        Unless there is another content.object, in which case it will go to that and
-        then get image. Sheesh.
+        Attempts to provide a representative image from a content_object based on 
+        the content objects' get_image() method. 
+        
+        If there is a another content.object, as in the case of comments and other GFKs,
+        then it will follow to that content_object and then get the image.
 
-        Requires get_image() to be defined on the related model
-        even if it just returns object.image, to avoid bringing back images you may not want.
+        Requires get_image() to be defined on the related model even if it just 
+        returns object.image, to avoid bringing back images you may not want.
 
         """
         obj = self.content_object
